/*
 * Copyright  20072010, Curtis Clifton and Brian T. Kelley
 * 
 * All rights reserved.
 * 
 * See license.txt for details.
 */

/***************************************************
 * Based on Lexical grammar for CFGs 
 * by Curt Clifton, modified by Brian Kelley
 * Rose-Hulman Institute of Technology
 * Copyright (C) 2006-07
 ***************************************************/
package edu.roseHulman.cfg.parsing;

import edu.roseHulman.cfg.EOFToken;
import edu.roseHulman.cfg.TerminalToken;
import edu.roseHulman.cfg.Token;
// --------------------------------------------------
// User Code
// --------------------------------------------------

%%
// --------------------------------------------------
// Options and Declarations
// --------------------------------------------------

//%debug
%public
%class StringInputScanner
%apiprivate
%type edu.roseHulman.cfg.Token

%unicode
%line
%column

%{
	/**
	 * Nicely named interface to the lexer.
	 */
	public Token nextToken() throws java.io.IOException {
		return yylex();
	}
%}

Whitespace = (\b|\t|\f|" ")*  // This probably isn't unicode
// Probably need to include whitespace between newlines
Newline = (\r|\n|\u2028|\u2029|\u000B|\u000C|\u0085)+
Terminal = [^\r\n\u2028\u2029\u000B\u000C\u0085\b\t\f ]+

%%
// --------------------------------------------------
// Lexical Rules
// --------------------------------------------------

<YYINITIAL> {
	// terminals
	{Terminal}				{ return new TerminalToken(yytext()); }
	
	// to ignore
	({Newline} {Whitespace}*)+	{ /* ignore */ }
	{Whitespace}				{ /* ignore */ }
	
}

// eof
<YYINITIAL>	<<EOF>>			{ return EOFToken.getInstance(); }

